// Package compensation code generated by oapi sdk gen
/*
 * MIT License
 *
 * Copyright (c) 2022 Lark Technologies Pte. Ltd.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice, shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package larkcompensation

import (
	"fmt"

	"context"
	"errors"

	"github.com/larksuite/oapi-sdk-go/v3/core"
)

const (
	UserIDTypeUserId  = "user_id"  // 以user_id来识别用户
	UserIDTypeUnionId = "union_id" // 以union_id来识别用户
	UserIDTypeOpenId  = "open_id"  // 以open_id来识别用户
)

type AdjustmentLogic struct {
	Fixed   *string  `json:"fixed,omitempty"`   // 固定值
	Formula *Formula `json:"formula,omitempty"` // 公式配置
}

type AdjustmentLogicBuilder struct {
	fixed       string // 固定值
	fixedFlag   bool
	formula     *Formula // 公式配置
	formulaFlag bool
}

func NewAdjustmentLogicBuilder() *AdjustmentLogicBuilder {
	builder := &AdjustmentLogicBuilder{}
	return builder
}

// 固定值
//
// 示例值：60
func (builder *AdjustmentLogicBuilder) Fixed(fixed string) *AdjustmentLogicBuilder {
	builder.fixed = fixed
	builder.fixedFlag = true
	return builder
}

// 公式配置
//
// 示例值：
func (builder *AdjustmentLogicBuilder) Formula(formula *Formula) *AdjustmentLogicBuilder {
	builder.formula = formula
	builder.formulaFlag = true
	return builder
}

func (builder *AdjustmentLogicBuilder) Build() *AdjustmentLogic {
	req := &AdjustmentLogic{}
	if builder.fixedFlag {
		req.Fixed = &builder.fixed

	}
	if builder.formulaFlag {
		req.Formula = builder.formula
	}
	return req
}

type Archive struct {
	ArchiveId     *string `json:"archive_id,omitempty"`     // 档案ID
	ArchiveTid    *string `json:"archive_tid,omitempty"`    // 档案时间轴版本ID
	UserId        *string `json:"user_id,omitempty"`        // 员工ID
	Plan          *Plan   `json:"plan,omitempty"`           // 关联方案
	EffectiveDate *string `json:"effective_date,omitempty"` // 档案生效时间
}

type ArchiveBuilder struct {
	archiveId         string // 档案ID
	archiveIdFlag     bool
	archiveTid        string // 档案时间轴版本ID
	archiveTidFlag    bool
	userId            string // 员工ID
	userIdFlag        bool
	plan              *Plan // 关联方案
	planFlag          bool
	effectiveDate     string // 档案生效时间
	effectiveDateFlag bool
}

func NewArchiveBuilder() *ArchiveBuilder {
	builder := &ArchiveBuilder{}
	return builder
}

// 档案ID
//
// 示例值：7196951947268589113
func (builder *ArchiveBuilder) ArchiveId(archiveId string) *ArchiveBuilder {
	builder.archiveId = archiveId
	builder.archiveIdFlag = true
	return builder
}

// 档案时间轴版本ID
//
// 示例值：7209959917078201911
func (builder *ArchiveBuilder) ArchiveTid(archiveTid string) *ArchiveBuilder {
	builder.archiveTid = archiveTid
	builder.archiveTidFlag = true
	return builder
}

// 员工ID
//
// 示例值：7117649868058789407
func (builder *ArchiveBuilder) UserId(userId string) *ArchiveBuilder {
	builder.userId = userId
	builder.userIdFlag = true
	return builder
}

// 关联方案
//
// 示例值：
func (builder *ArchiveBuilder) Plan(plan *Plan) *ArchiveBuilder {
	builder.plan = plan
	builder.planFlag = true
	return builder
}

// 档案生效时间
//
// 示例值：2022-03-18
func (builder *ArchiveBuilder) EffectiveDate(effectiveDate string) *ArchiveBuilder {
	builder.effectiveDate = effectiveDate
	builder.effectiveDateFlag = true
	return builder
}

func (builder *ArchiveBuilder) Build() *Archive {
	req := &Archive{}
	if builder.archiveIdFlag {
		req.ArchiveId = &builder.archiveId

	}
	if builder.archiveTidFlag {
		req.ArchiveTid = &builder.archiveTid

	}
	if builder.userIdFlag {
		req.UserId = &builder.userId

	}
	if builder.planFlag {
		req.Plan = builder.plan
	}
	if builder.effectiveDateFlag {
		req.EffectiveDate = &builder.effectiveDate

	}
	return req
}

type ArchiveDetail struct {
	UserId            *string             `json:"user_id,omitempty"`            // 员工ID
	Id                *string             `json:"id,omitempty"`                 // 档案ID
	Tid               *string             `json:"tid,omitempty"`                // 档案TID
	PlanId            *string             `json:"plan_id,omitempty"`            // 关联方案ID，详细信息可以通过[批量查询薪资方案](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/plan/list)接口查询获得
	PlanTid           *string             `json:"plan_tid,omitempty"`           // 关联方案TID，详细信息可以通过[批量查询薪资方案](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/plan/list)接口查询获得
	CurrencyId        *string             `json:"currency_id,omitempty"`        // 档案币种ID，详细信息可以通过[查询货币信息v2](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/corehr-v2/basic_info-currency/search)接口查询获得
	ChangeReasonId    *string             `json:"change_reason_id,omitempty"`   // 调薪原因ID，详细信息可以通过[批量查询定调薪原因](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/change_reason/list)接口查询获得
	ChangeDescription *string             `json:"change_description,omitempty"` // 调薪说明
	EffectiveDate     *string             `json:"effective_date,omitempty"`     // 生效时间
	SalaryLevelId     *string             `json:"salary_level_id,omitempty"`    // 薪级薪等ID
	ArchiveItems      []*ArchiveItem      `json:"archive_items,omitempty"`      // 档案关联的薪资项
	ArchiveIndicators []*ArchiveIndicator `json:"archive_indicators,omitempty"` // 档案关联的薪资指标
}

type ArchiveDetailBuilder struct {
	userId                string // 员工ID
	userIdFlag            bool
	id                    string // 档案ID
	idFlag                bool
	tid                   string // 档案TID
	tidFlag               bool
	planId                string // 关联方案ID，详细信息可以通过[批量查询薪资方案](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/plan/list)接口查询获得
	planIdFlag            bool
	planTid               string // 关联方案TID，详细信息可以通过[批量查询薪资方案](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/plan/list)接口查询获得
	planTidFlag           bool
	currencyId            string // 档案币种ID，详细信息可以通过[查询货币信息v2](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/corehr-v2/basic_info-currency/search)接口查询获得
	currencyIdFlag        bool
	changeReasonId        string // 调薪原因ID，详细信息可以通过[批量查询定调薪原因](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/change_reason/list)接口查询获得
	changeReasonIdFlag    bool
	changeDescription     string // 调薪说明
	changeDescriptionFlag bool
	effectiveDate         string // 生效时间
	effectiveDateFlag     bool
	salaryLevelId         string // 薪级薪等ID
	salaryLevelIdFlag     bool
	archiveItems          []*ArchiveItem // 档案关联的薪资项
	archiveItemsFlag      bool
	archiveIndicators     []*ArchiveIndicator // 档案关联的薪资指标
	archiveIndicatorsFlag bool
}

func NewArchiveDetailBuilder() *ArchiveDetailBuilder {
	builder := &ArchiveDetailBuilder{}
	return builder
}

// 员工ID
//
// 示例值：344325234123
func (builder *ArchiveDetailBuilder) UserId(userId string) *ArchiveDetailBuilder {
	builder.userId = userId
	builder.userIdFlag = true
	return builder
}

// 档案ID
//
// 示例值：32141234412
func (builder *ArchiveDetailBuilder) Id(id string) *ArchiveDetailBuilder {
	builder.id = id
	builder.idFlag = true
	return builder
}

// 档案TID
//
// 示例值：141541351
func (builder *ArchiveDetailBuilder) Tid(tid string) *ArchiveDetailBuilder {
	builder.tid = tid
	builder.tidFlag = true
	return builder
}

// 关联方案ID，详细信息可以通过[批量查询薪资方案](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/plan/list)接口查询获得
//
// 示例值：123412433
func (builder *ArchiveDetailBuilder) PlanId(planId string) *ArchiveDetailBuilder {
	builder.planId = planId
	builder.planIdFlag = true
	return builder
}

// 关联方案TID，详细信息可以通过[批量查询薪资方案](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/plan/list)接口查询获得
//
// 示例值：213412343
func (builder *ArchiveDetailBuilder) PlanTid(planTid string) *ArchiveDetailBuilder {
	builder.planTid = planTid
	builder.planTidFlag = true
	return builder
}

// 档案币种ID，详细信息可以通过[查询货币信息v2](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/corehr-v2/basic_info-currency/search)接口查询获得
//
// 示例值：324167823
func (builder *ArchiveDetailBuilder) CurrencyId(currencyId string) *ArchiveDetailBuilder {
	builder.currencyId = currencyId
	builder.currencyIdFlag = true
	return builder
}

// 调薪原因ID，详细信息可以通过[批量查询定调薪原因](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/change_reason/list)接口查询获得
//
// 示例值：321414123
func (builder *ArchiveDetailBuilder) ChangeReasonId(changeReasonId string) *ArchiveDetailBuilder {
	builder.changeReasonId = changeReasonId
	builder.changeReasonIdFlag = true
	return builder
}

// 调薪说明
//
// 示例值：长期表现优异，产出高，本次给出涨幅
func (builder *ArchiveDetailBuilder) ChangeDescription(changeDescription string) *ArchiveDetailBuilder {
	builder.changeDescription = changeDescription
	builder.changeDescriptionFlag = true
	return builder
}

// 生效时间
//
// 示例值：2022-10-23
func (builder *ArchiveDetailBuilder) EffectiveDate(effectiveDate string) *ArchiveDetailBuilder {
	builder.effectiveDate = effectiveDate
	builder.effectiveDateFlag = true
	return builder
}

// 薪级薪等ID
//
// 示例值：12342313
func (builder *ArchiveDetailBuilder) SalaryLevelId(salaryLevelId string) *ArchiveDetailBuilder {
	builder.salaryLevelId = salaryLevelId
	builder.salaryLevelIdFlag = true
	return builder
}

// 档案关联的薪资项
//
// 示例值：
func (builder *ArchiveDetailBuilder) ArchiveItems(archiveItems []*ArchiveItem) *ArchiveDetailBuilder {
	builder.archiveItems = archiveItems
	builder.archiveItemsFlag = true
	return builder
}

// 档案关联的薪资指标
//
// 示例值：
func (builder *ArchiveDetailBuilder) ArchiveIndicators(archiveIndicators []*ArchiveIndicator) *ArchiveDetailBuilder {
	builder.archiveIndicators = archiveIndicators
	builder.archiveIndicatorsFlag = true
	return builder
}

func (builder *ArchiveDetailBuilder) Build() *ArchiveDetail {
	req := &ArchiveDetail{}
	if builder.userIdFlag {
		req.UserId = &builder.userId

	}
	if builder.idFlag {
		req.Id = &builder.id

	}
	if builder.tidFlag {
		req.Tid = &builder.tid

	}
	if builder.planIdFlag {
		req.PlanId = &builder.planId

	}
	if builder.planTidFlag {
		req.PlanTid = &builder.planTid

	}
	if builder.currencyIdFlag {
		req.CurrencyId = &builder.currencyId

	}
	if builder.changeReasonIdFlag {
		req.ChangeReasonId = &builder.changeReasonId

	}
	if builder.changeDescriptionFlag {
		req.ChangeDescription = &builder.changeDescription

	}
	if builder.effectiveDateFlag {
		req.EffectiveDate = &builder.effectiveDate

	}
	if builder.salaryLevelIdFlag {
		req.SalaryLevelId = &builder.salaryLevelId

	}
	if builder.archiveItemsFlag {
		req.ArchiveItems = builder.archiveItems
	}
	if builder.archiveIndicatorsFlag {
		req.ArchiveIndicators = builder.archiveIndicators
	}
	return req
}

type ArchiveIndicator struct {
	IndicatorId            *string `json:"indicator_id,omitempty"`             // 薪资统计指标ID，详细信息可以通过[批量查询薪资统计指标](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/indicator/list)接口查询获得
	IndicatorResult        *string `json:"indicator_result,omitempty"`         // 档案关联薪资统计指标数值
	IndicatorResultRegular *string `json:"indicator_result_regular,omitempty"` // 档案关联薪资统计指标转正后数值
}

type ArchiveIndicatorBuilder struct {
	indicatorId                string // 薪资统计指标ID，详细信息可以通过[批量查询薪资统计指标](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/indicator/list)接口查询获得
	indicatorIdFlag            bool
	indicatorResult            string // 档案关联薪资统计指标数值
	indicatorResultFlag        bool
	indicatorResultRegular     string // 档案关联薪资统计指标转正后数值
	indicatorResultRegularFlag bool
}

func NewArchiveIndicatorBuilder() *ArchiveIndicatorBuilder {
	builder := &ArchiveIndicatorBuilder{}
	return builder
}

// 薪资统计指标ID，详细信息可以通过[批量查询薪资统计指标](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/indicator/list)接口查询获得
//
// 示例值：23141423
func (builder *ArchiveIndicatorBuilder) IndicatorId(indicatorId string) *ArchiveIndicatorBuilder {
	builder.indicatorId = indicatorId
	builder.indicatorIdFlag = true
	return builder
}

// 档案关联薪资统计指标数值
//
// 示例值：15000
func (builder *ArchiveIndicatorBuilder) IndicatorResult(indicatorResult string) *ArchiveIndicatorBuilder {
	builder.indicatorResult = indicatorResult
	builder.indicatorResultFlag = true
	return builder
}

// 档案关联薪资统计指标转正后数值
//
// 示例值：18000
func (builder *ArchiveIndicatorBuilder) IndicatorResultRegular(indicatorResultRegular string) *ArchiveIndicatorBuilder {
	builder.indicatorResultRegular = indicatorResultRegular
	builder.indicatorResultRegularFlag = true
	return builder
}

func (builder *ArchiveIndicatorBuilder) Build() *ArchiveIndicator {
	req := &ArchiveIndicator{}
	if builder.indicatorIdFlag {
		req.IndicatorId = &builder.indicatorId

	}
	if builder.indicatorResultFlag {
		req.IndicatorResult = &builder.indicatorResult

	}
	if builder.indicatorResultRegularFlag {
		req.IndicatorResultRegular = &builder.indicatorResultRegular

	}
	return req
}

type ArchiveItem struct {
	ItemId            *string `json:"item_id,omitempty"`             // 薪资项ID，详细信息可以通过[批量查询薪资项](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/item/list)接口查询获得
	ItemResult        *string `json:"item_result,omitempty"`         // 档案关联薪资项数值
	ItemResultRegular *string `json:"item_result_regular,omitempty"` // 档案关联薪资项转正后数值
}

type ArchiveItemBuilder struct {
	itemId                string // 薪资项ID，详细信息可以通过[批量查询薪资项](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/item/list)接口查询获得
	itemIdFlag            bool
	itemResult            string // 档案关联薪资项数值
	itemResultFlag        bool
	itemResultRegular     string // 档案关联薪资项转正后数值
	itemResultRegularFlag bool
}

func NewArchiveItemBuilder() *ArchiveItemBuilder {
	builder := &ArchiveItemBuilder{}
	return builder
}

// 薪资项ID，详细信息可以通过[批量查询薪资项](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/item/list)接口查询获得
//
// 示例值：213423144
func (builder *ArchiveItemBuilder) ItemId(itemId string) *ArchiveItemBuilder {
	builder.itemId = itemId
	builder.itemIdFlag = true
	return builder
}

// 档案关联薪资项数值
//
// 示例值：15000
func (builder *ArchiveItemBuilder) ItemResult(itemResult string) *ArchiveItemBuilder {
	builder.itemResult = itemResult
	builder.itemResultFlag = true
	return builder
}

// 档案关联薪资项转正后数值
//
// 示例值：18000
func (builder *ArchiveItemBuilder) ItemResultRegular(itemResultRegular string) *ArchiveItemBuilder {
	builder.itemResultRegular = itemResultRegular
	builder.itemResultRegularFlag = true
	return builder
}

func (builder *ArchiveItemBuilder) Build() *ArchiveItem {
	req := &ArchiveItem{}
	if builder.itemIdFlag {
		req.ItemId = &builder.itemId

	}
	if builder.itemResultFlag {
		req.ItemResult = &builder.itemResult

	}
	if builder.itemResultRegularFlag {
		req.ItemResultRegular = &builder.itemResultRegular

	}
	return req
}

type ChangeReason struct {
	Id           *string        `json:"id,omitempty"`            // 调薪原因ID
	Name         *string        `json:"name,omitempty"`          // 调薪原因名称
	Note         *string        `json:"note,omitempty"`          // 调薪原因备注
	ActiveStatus *int           `json:"active_status,omitempty"` // 启用状态
	I18nNames    []*I18nContent `json:"i18n_names,omitempty"`    // 多语言名称
	I18nNotes    []*I18nContent `json:"i18n_notes,omitempty"`    // 多语言描述
}

type ChangeReasonBuilder struct {
	id               string // 调薪原因ID
	idFlag           bool
	name             string // 调薪原因名称
	nameFlag         bool
	note             string // 调薪原因备注
	noteFlag         bool
	activeStatus     int // 启用状态
	activeStatusFlag bool
	i18nNames        []*I18nContent // 多语言名称
	i18nNamesFlag    bool
	i18nNotes        []*I18nContent // 多语言描述
	i18nNotesFlag    bool
}

func NewChangeReasonBuilder() *ChangeReasonBuilder {
	builder := &ChangeReasonBuilder{}
	return builder
}

// 调薪原因ID
//
// 示例值：7196951947268589113
func (builder *ChangeReasonBuilder) Id(id string) *ChangeReasonBuilder {
	builder.id = id
	builder.idFlag = true
	return builder
}

// 调薪原因名称
//
// 示例值：入职调薪
func (builder *ChangeReasonBuilder) Name(name string) *ChangeReasonBuilder {
	builder.name = name
	builder.nameFlag = true
	return builder
}

// 调薪原因备注
//
// 示例值：入职时使用的调薪原因
func (builder *ChangeReasonBuilder) Note(note string) *ChangeReasonBuilder {
	builder.note = note
	builder.noteFlag = true
	return builder
}

// 启用状态
//
// 示例值：1
func (builder *ChangeReasonBuilder) ActiveStatus(activeStatus int) *ChangeReasonBuilder {
	builder.activeStatus = activeStatus
	builder.activeStatusFlag = true
	return builder
}

// 多语言名称
//
// 示例值：
func (builder *ChangeReasonBuilder) I18nNames(i18nNames []*I18nContent) *ChangeReasonBuilder {
	builder.i18nNames = i18nNames
	builder.i18nNamesFlag = true
	return builder
}

// 多语言描述
//
// 示例值：
func (builder *ChangeReasonBuilder) I18nNotes(i18nNotes []*I18nContent) *ChangeReasonBuilder {
	builder.i18nNotes = i18nNotes
	builder.i18nNotesFlag = true
	return builder
}

func (builder *ChangeReasonBuilder) Build() *ChangeReason {
	req := &ChangeReason{}
	if builder.idFlag {
		req.Id = &builder.id

	}
	if builder.nameFlag {
		req.Name = &builder.name

	}
	if builder.noteFlag {
		req.Note = &builder.note

	}
	if builder.activeStatusFlag {
		req.ActiveStatus = &builder.activeStatus

	}
	if builder.i18nNamesFlag {
		req.I18nNames = builder.i18nNames
	}
	if builder.i18nNotesFlag {
		req.I18nNotes = builder.i18nNotes
	}
	return req
}

type DepartmentId struct {
	DepartmentId     *string `json:"department_id,omitempty"`      //
	OpenDepartmentId *string `json:"open_department_id,omitempty"` //
}

type DepartmentIdBuilder struct {
	departmentId         string //
	departmentIdFlag     bool
	openDepartmentId     string //
	openDepartmentIdFlag bool
}

func NewDepartmentIdBuilder() *DepartmentIdBuilder {
	builder := &DepartmentIdBuilder{}
	return builder
}

// 示例值：
func (builder *DepartmentIdBuilder) DepartmentId(departmentId string) *DepartmentIdBuilder {
	builder.departmentId = departmentId
	builder.departmentIdFlag = true
	return builder
}

// 示例值：
func (builder *DepartmentIdBuilder) OpenDepartmentId(openDepartmentId string) *DepartmentIdBuilder {
	builder.openDepartmentId = openDepartmentId
	builder.openDepartmentIdFlag = true
	return builder
}

func (builder *DepartmentIdBuilder) Build() *DepartmentId {
	req := &DepartmentId{}
	if builder.departmentIdFlag {
		req.DepartmentId = &builder.departmentId

	}
	if builder.openDepartmentIdFlag {
		req.OpenDepartmentId = &builder.openDepartmentId

	}
	return req
}

type Formula struct {
	Expr          *string         `json:"expr,omitempty"`           // 公式表达式
	FormulaParams []*FormulaParam `json:"formula_params,omitempty"` // 公式参数列表
}

type FormulaBuilder struct {
	expr              string // 公式表达式
	exprFlag          bool
	formulaParams     []*FormulaParam // 公式参数列表
	formulaParamsFlag bool
}

func NewFormulaBuilder() *FormulaBuilder {
	builder := &FormulaBuilder{}
	return builder
}

// 公式表达式
//
// 示例值：${0} +${1}
func (builder *FormulaBuilder) Expr(expr string) *FormulaBuilder {
	builder.expr = expr
	builder.exprFlag = true
	return builder
}

// 公式参数列表
//
// 示例值：
func (builder *FormulaBuilder) FormulaParams(formulaParams []*FormulaParam) *FormulaBuilder {
	builder.formulaParams = formulaParams
	builder.formulaParamsFlag = true
	return builder
}

func (builder *FormulaBuilder) Build() *Formula {
	req := &Formula{}
	if builder.exprFlag {
		req.Expr = &builder.expr

	}
	if builder.formulaParamsFlag {
		req.FormulaParams = builder.formulaParams
	}
	return req
}

type FormulaParam struct {
	RefType *int    `json:"ref_type,omitempty"` // 引用类型
	Id      *string `json:"id,omitempty"`       // 引用类型ID
}

type FormulaParamBuilder struct {
	refType     int // 引用类型
	refTypeFlag bool
	id          string // 引用类型ID
	idFlag      bool
}

func NewFormulaParamBuilder() *FormulaParamBuilder {
	builder := &FormulaParamBuilder{}
	return builder
}

// 引用类型
//
// 示例值：1
func (builder *FormulaParamBuilder) RefType(refType int) *FormulaParamBuilder {
	builder.refType = refType
	builder.refTypeFlag = true
	return builder
}

// 引用类型ID
//
// 示例值：23143242
func (builder *FormulaParamBuilder) Id(id string) *FormulaParamBuilder {
	builder.id = id
	builder.idFlag = true
	return builder
}

func (builder *FormulaParamBuilder) Build() *FormulaParam {
	req := &FormulaParam{}
	if builder.refTypeFlag {
		req.RefType = &builder.refType

	}
	if builder.idFlag {
		req.Id = &builder.id

	}
	return req
}

type I18n struct {
	ZhCn *string `json:"zh_cn,omitempty"` // 中文名称
	EnUs *string `json:"en_us,omitempty"` // 英文名称
}

type I18nBuilder struct {
	zhCn     string // 中文名称
	zhCnFlag bool
	enUs     string // 英文名称
	enUsFlag bool
}

func NewI18nBuilder() *I18nBuilder {
	builder := &I18nBuilder{}
	return builder
}

// 中文名称
//
// 示例值：中文名称
func (builder *I18nBuilder) ZhCn(zhCn string) *I18nBuilder {
	builder.zhCn = zhCn
	builder.zhCnFlag = true
	return builder
}

// 英文名称
//
// 示例值：english_name
func (builder *I18nBuilder) EnUs(enUs string) *I18nBuilder {
	builder.enUs = enUs
	builder.enUsFlag = true
	return builder
}

func (builder *I18nBuilder) Build() *I18n {
	req := &I18n{}
	if builder.zhCnFlag {
		req.ZhCn = &builder.zhCn

	}
	if builder.enUsFlag {
		req.EnUs = &builder.enUs

	}
	return req
}

type I18nContent struct {
	Locale *string `json:"locale,omitempty"` // 语言版本
	Value  *string `json:"value,omitempty"`  // 语言名称
}

type I18nContentBuilder struct {
	locale     string // 语言版本
	localeFlag bool
	value      string // 语言名称
	valueFlag  bool
}

func NewI18nContentBuilder() *I18nContentBuilder {
	builder := &I18nContentBuilder{}
	return builder
}

// 语言版本
//
// 示例值：zh_cn
func (builder *I18nContentBuilder) Locale(locale string) *I18nContentBuilder {
	builder.locale = locale
	builder.localeFlag = true
	return builder
}

// 语言名称
//
// 示例值：中文名称
func (builder *I18nContentBuilder) Value(value string) *I18nContentBuilder {
	builder.value = value
	builder.valueFlag = true
	return builder
}

func (builder *I18nContentBuilder) Build() *I18nContent {
	req := &I18nContent{}
	if builder.localeFlag {
		req.Locale = &builder.locale

	}
	if builder.valueFlag {
		req.Value = &builder.value

	}
	return req
}

type Indicator struct {
	Id           *string        `json:"id,omitempty"`            // 薪资统计指标ID
	Name         *string        `json:"name,omitempty"`          // 薪资统计指标名称
	ValueType    *string        `json:"value_type,omitempty"`    // 薪资统计指标数值类型
	ActiveStatus *int           `json:"active_status,omitempty"` // 启用状态
	I18nNames    []*I18nContent `json:"i18n_names,omitempty"`    // 多语言名称
}

type IndicatorBuilder struct {
	id               string // 薪资统计指标ID
	idFlag           bool
	name             string // 薪资统计指标名称
	nameFlag         bool
	valueType        string // 薪资统计指标数值类型
	valueTypeFlag    bool
	activeStatus     int // 启用状态
	activeStatusFlag bool
	i18nNames        []*I18nContent // 多语言名称
	i18nNamesFlag    bool
}

func NewIndicatorBuilder() *IndicatorBuilder {
	builder := &IndicatorBuilder{}
	return builder
}

// 薪资统计指标ID
//
// 示例值：7196951947228589113
func (builder *IndicatorBuilder) Id(id string) *IndicatorBuilder {
	builder.id = id
	builder.idFlag = true
	return builder
}

// 薪资统计指标名称
//
// 示例值：年度现金总和
func (builder *IndicatorBuilder) Name(name string) *IndicatorBuilder {
	builder.name = name
	builder.nameFlag = true
	return builder
}

// 薪资统计指标数值类型
//
// 示例值：money
func (builder *IndicatorBuilder) ValueType(valueType string) *IndicatorBuilder {
	builder.valueType = valueType
	builder.valueTypeFlag = true
	return builder
}

// 启用状态
//
// 示例值：1
func (builder *IndicatorBuilder) ActiveStatus(activeStatus int) *IndicatorBuilder {
	builder.activeStatus = activeStatus
	builder.activeStatusFlag = true
	return builder
}

// 多语言名称
//
// 示例值：
func (builder *IndicatorBuilder) I18nNames(i18nNames []*I18nContent) *IndicatorBuilder {
	builder.i18nNames = i18nNames
	builder.i18nNamesFlag = true
	return builder
}

func (builder *IndicatorBuilder) Build() *Indicator {
	req := &Indicator{}
	if builder.idFlag {
		req.Id = &builder.id

	}
	if builder.nameFlag {
		req.Name = &builder.name

	}
	if builder.valueTypeFlag {
		req.ValueType = &builder.valueType

	}
	if builder.activeStatusFlag {
		req.ActiveStatus = &builder.activeStatus

	}
	if builder.i18nNamesFlag {
		req.I18nNames = builder.i18nNames
	}
	return req
}

type Item struct {
	Id                  *string        `json:"id,omitempty"`                     // 薪资项ID
	Name                *string        `json:"name,omitempty"`                   // 薪资项名称
	Description         *string        `json:"description,omitempty"`            // 薪资项描述
	CategoryId          *string        `json:"category_id,omitempty"`            // 薪资项分类ID，详细信息可以通过[批量获取薪资项分类信息](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/item_category/list)接口查询获得
	ValueType           *string        `json:"value_type,omitempty"`             // 薪资项数值类型
	PayOffFrequencyType *string        `json:"pay_off_frequency_type,omitempty"` // 发放频率
	DecimalPlaces       *int           `json:"decimal_places,omitempty"`         // 小数位数
	ActiveStatus        *int           `json:"active_status,omitempty"`          // 启用状态
	I18nNames           []*I18nContent `json:"i18n_names,omitempty"`             // 多语言名称
	I18nDescriptions    []*I18nContent `json:"i18n_descriptions,omitempty"`      // 多语言描述
}

type ItemBuilder struct {
	id                      string // 薪资项ID
	idFlag                  bool
	name                    string // 薪资项名称
	nameFlag                bool
	description             string // 薪资项描述
	descriptionFlag         bool
	categoryId              string // 薪资项分类ID，详细信息可以通过[批量获取薪资项分类信息](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/item_category/list)接口查询获得
	categoryIdFlag          bool
	valueType               string // 薪资项数值类型
	valueTypeFlag           bool
	payOffFrequencyType     string // 发放频率
	payOffFrequencyTypeFlag bool
	decimalPlaces           int // 小数位数
	decimalPlacesFlag       bool
	activeStatus            int // 启用状态
	activeStatusFlag        bool
	i18nNames               []*I18nContent // 多语言名称
	i18nNamesFlag           bool
	i18nDescriptions        []*I18nContent // 多语言描述
	i18nDescriptionsFlag    bool
}

func NewItemBuilder() *ItemBuilder {
	builder := &ItemBuilder{}
	return builder
}

// 薪资项ID
//
// 示例值：7196951947268589113
func (builder *ItemBuilder) Id(id string) *ItemBuilder {
	builder.id = id
	builder.idFlag = true
	return builder
}

// 薪资项名称
//
// 示例值：基本月薪
func (builder *ItemBuilder) Name(name string) *ItemBuilder {
	builder.name = name
	builder.nameFlag = true
	return builder
}

// 薪资项描述
//
// 示例值：每月份的薪酬
func (builder *ItemBuilder) Description(description string) *ItemBuilder {
	builder.description = description
	builder.descriptionFlag = true
	return builder
}

// 薪资项分类ID，详细信息可以通过[批量获取薪资项分类信息](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/item_category/list)接口查询获得
//
// 示例值：7196951947268589223
func (builder *ItemBuilder) CategoryId(categoryId string) *ItemBuilder {
	builder.categoryId = categoryId
	builder.categoryIdFlag = true
	return builder
}

// 薪资项数值类型
//
// 示例值：money
func (builder *ItemBuilder) ValueType(valueType string) *ItemBuilder {
	builder.valueType = valueType
	builder.valueTypeFlag = true
	return builder
}

// 发放频率
//
// 示例值：month
func (builder *ItemBuilder) PayOffFrequencyType(payOffFrequencyType string) *ItemBuilder {
	builder.payOffFrequencyType = payOffFrequencyType
	builder.payOffFrequencyTypeFlag = true
	return builder
}

// 小数位数
//
// 示例值：2
func (builder *ItemBuilder) DecimalPlaces(decimalPlaces int) *ItemBuilder {
	builder.decimalPlaces = decimalPlaces
	builder.decimalPlacesFlag = true
	return builder
}

// 启用状态
//
// 示例值：1
func (builder *ItemBuilder) ActiveStatus(activeStatus int) *ItemBuilder {
	builder.activeStatus = activeStatus
	builder.activeStatusFlag = true
	return builder
}

// 多语言名称
//
// 示例值：
func (builder *ItemBuilder) I18nNames(i18nNames []*I18nContent) *ItemBuilder {
	builder.i18nNames = i18nNames
	builder.i18nNamesFlag = true
	return builder
}

// 多语言描述
//
// 示例值：
func (builder *ItemBuilder) I18nDescriptions(i18nDescriptions []*I18nContent) *ItemBuilder {
	builder.i18nDescriptions = i18nDescriptions
	builder.i18nDescriptionsFlag = true
	return builder
}

func (builder *ItemBuilder) Build() *Item {
	req := &Item{}
	if builder.idFlag {
		req.Id = &builder.id

	}
	if builder.nameFlag {
		req.Name = &builder.name

	}
	if builder.descriptionFlag {
		req.Description = &builder.description

	}
	if builder.categoryIdFlag {
		req.CategoryId = &builder.categoryId

	}
	if builder.valueTypeFlag {
		req.ValueType = &builder.valueType

	}
	if builder.payOffFrequencyTypeFlag {
		req.PayOffFrequencyType = &builder.payOffFrequencyType

	}
	if builder.decimalPlacesFlag {
		req.DecimalPlaces = &builder.decimalPlaces

	}
	if builder.activeStatusFlag {
		req.ActiveStatus = &builder.activeStatus

	}
	if builder.i18nNamesFlag {
		req.I18nNames = builder.i18nNames
	}
	if builder.i18nDescriptionsFlag {
		req.I18nDescriptions = builder.i18nDescriptions
	}
	return req
}

type ItemCategory struct {
	Id        *string        `json:"id,omitempty"`         // 薪资项分类ID
	Name      *string        `json:"name,omitempty"`       // 薪资项分类名称
	I18nNames []*I18nContent `json:"i18n_names,omitempty"` // 薪资项多语言分类
}

type ItemCategoryBuilder struct {
	id            string // 薪资项分类ID
	idFlag        bool
	name          string // 薪资项分类名称
	nameFlag      bool
	i18nNames     []*I18nContent // 薪资项多语言分类
	i18nNamesFlag bool
}

func NewItemCategoryBuilder() *ItemCategoryBuilder {
	builder := &ItemCategoryBuilder{}
	return builder
}

// 薪资项分类ID
//
// 示例值：4532312334
func (builder *ItemCategoryBuilder) Id(id string) *ItemCategoryBuilder {
	builder.id = id
	builder.idFlag = true
	return builder
}

// 薪资项分类名称
//
// 示例值：基本薪资类
func (builder *ItemCategoryBuilder) Name(name string) *ItemCategoryBuilder {
	builder.name = name
	builder.nameFlag = true
	return builder
}

// 薪资项多语言分类
//
// 示例值：
func (builder *ItemCategoryBuilder) I18nNames(i18nNames []*I18nContent) *ItemCategoryBuilder {
	builder.i18nNames = i18nNames
	builder.i18nNamesFlag = true
	return builder
}

func (builder *ItemCategoryBuilder) Build() *ItemCategory {
	req := &ItemCategory{}
	if builder.idFlag {
		req.Id = &builder.id

	}
	if builder.nameFlag {
		req.Name = &builder.name

	}
	if builder.i18nNamesFlag {
		req.I18nNames = builder.i18nNames
	}
	return req
}

type Plan struct {
	PlanId   *string `json:"plan_id,omitempty"`   // 方案ID
	PlanTid  *string `json:"plan_tid,omitempty"`  // 方案时间轴版本ID
	Name     *I18n   `json:"name,omitempty"`      // 方案名称
	PeopleId *int    `json:"people_id,omitempty"` // People系统方案ID
}

type PlanBuilder struct {
	planId       string // 方案ID
	planIdFlag   bool
	planTid      string // 方案时间轴版本ID
	planTidFlag  bool
	name         *I18n // 方案名称
	nameFlag     bool
	peopleId     int // People系统方案ID
	peopleIdFlag bool
}

func NewPlanBuilder() *PlanBuilder {
	builder := &PlanBuilder{}
	return builder
}

// 方案ID
//
// 示例值：7234781378700985913
func (builder *PlanBuilder) PlanId(planId string) *PlanBuilder {
	builder.planId = planId
	builder.planIdFlag = true
	return builder
}

// 方案时间轴版本ID
//
// 示例值：7137286102364227108
func (builder *PlanBuilder) PlanTid(planTid string) *PlanBuilder {
	builder.planTid = planTid
	builder.planTidFlag = true
	return builder
}

// 方案名称
//
// 示例值：
func (builder *PlanBuilder) Name(name *I18n) *PlanBuilder {
	builder.name = name
	builder.nameFlag = true
	return builder
}

// People系统方案ID
//
// 示例值：20
func (builder *PlanBuilder) PeopleId(peopleId int) *PlanBuilder {
	builder.peopleId = peopleId
	builder.peopleIdFlag = true
	return builder
}

func (builder *PlanBuilder) Build() *Plan {
	req := &Plan{}
	if builder.planIdFlag {
		req.PlanId = &builder.planId

	}
	if builder.planTidFlag {
		req.PlanTid = &builder.planTid

	}
	if builder.nameFlag {
		req.Name = builder.name
	}
	if builder.peopleIdFlag {
		req.PeopleId = &builder.peopleId

	}
	return req
}

type PlanCondition struct {
	LeftType   *int     `json:"left_type,omitempty"`   // 适用范围左值
	Operator   *int     `json:"operator,omitempty"`    // 适用范围操作
	RightValue []string `json:"right_value,omitempty"` // 适用范围右值
}

type PlanConditionBuilder struct {
	leftType       int // 适用范围左值
	leftTypeFlag   bool
	operator       int // 适用范围操作
	operatorFlag   bool
	rightValue     []string // 适用范围右值
	rightValueFlag bool
}

func NewPlanConditionBuilder() *PlanConditionBuilder {
	builder := &PlanConditionBuilder{}
	return builder
}

// 适用范围左值
//
// 示例值：7
func (builder *PlanConditionBuilder) LeftType(leftType int) *PlanConditionBuilder {
	builder.leftType = leftType
	builder.leftTypeFlag = true
	return builder
}

// 适用范围操作
//
// 示例值：1
func (builder *PlanConditionBuilder) Operator(operator int) *PlanConditionBuilder {
	builder.operator = operator
	builder.operatorFlag = true
	return builder
}

// 适用范围右值
//
// 示例值：21341234
func (builder *PlanConditionBuilder) RightValue(rightValue []string) *PlanConditionBuilder {
	builder.rightValue = rightValue
	builder.rightValueFlag = true
	return builder
}

func (builder *PlanConditionBuilder) Build() *PlanCondition {
	req := &PlanCondition{}
	if builder.leftTypeFlag {
		req.LeftType = &builder.leftType

	}
	if builder.operatorFlag {
		req.Operator = &builder.operator

	}
	if builder.rightValueFlag {
		req.RightValue = builder.rightValue
	}
	return req
}

type PlanDetail struct {
	Id                    *string          `json:"id,omitempty"`                      // 薪资方案ID
	Tid                   *string          `json:"tid,omitempty"`                     // 薪资方案TID
	Name                  *string          `json:"name,omitempty"`                    // 薪资方案名称
	Description           *string          `json:"description,omitempty"`             // 薪资方案描述
	EffectiveDate         *string          `json:"effective_date,omitempty"`          // 薪资方案生效时间
	PlanScope             *PlanScope       `json:"plan_scope,omitempty"`              // 薪资方案适用范围
	CurrencyId            *string          `json:"currency_id,omitempty"`             // 币种ID
	ProbationSalaryStatus *bool            `json:"probation_salary_status,omitempty"` // 开启试用期薪酬状态
	PlanItems             []*PlanItem      `json:"plan_items,omitempty"`              // 方案关联的薪资项
	PlanIndicators        []*PlanIndicator `json:"plan_indicators,omitempty"`         // 方案关联的薪资统计指标
	I18nNames             []*I18nContent   `json:"i18n_names,omitempty"`              // 多语言名称
	I18nDescriptions      []*I18nContent   `json:"i18n_descriptions,omitempty"`       // 多语言描述
}

type PlanDetailBuilder struct {
	id                        string // 薪资方案ID
	idFlag                    bool
	tid                       string // 薪资方案TID
	tidFlag                   bool
	name                      string // 薪资方案名称
	nameFlag                  bool
	description               string // 薪资方案描述
	descriptionFlag           bool
	effectiveDate             string // 薪资方案生效时间
	effectiveDateFlag         bool
	planScope                 *PlanScope // 薪资方案适用范围
	planScopeFlag             bool
	currencyId                string // 币种ID
	currencyIdFlag            bool
	probationSalaryStatus     bool // 开启试用期薪酬状态
	probationSalaryStatusFlag bool
	planItems                 []*PlanItem // 方案关联的薪资项
	planItemsFlag             bool
	planIndicators            []*PlanIndicator // 方案关联的薪资统计指标
	planIndicatorsFlag        bool
	i18nNames                 []*I18nContent // 多语言名称
	i18nNamesFlag             bool
	i18nDescriptions          []*I18nContent // 多语言描述
	i18nDescriptionsFlag      bool
}

func NewPlanDetailBuilder() *PlanDetailBuilder {
	builder := &PlanDetailBuilder{}
	return builder
}

// 薪资方案ID
//
// 示例值：2134193289
func (builder *PlanDetailBuilder) Id(id string) *PlanDetailBuilder {
	builder.id = id
	builder.idFlag = true
	return builder
}

// 薪资方案TID
//
// 示例值：129738122
func (builder *PlanDetailBuilder) Tid(tid string) *PlanDetailBuilder {
	builder.tid = tid
	builder.tidFlag = true
	return builder
}

// 薪资方案名称
//
// 示例值：基本月薪方案
func (builder *PlanDetailBuilder) Name(name string) *PlanDetailBuilder {
	builder.name = name
	builder.nameFlag = true
	return builder
}

// 薪资方案描述
//
// 示例值：基本月薪方案描述
func (builder *PlanDetailBuilder) Description(description string) *PlanDetailBuilder {
	builder.description = description
	builder.descriptionFlag = true
	return builder
}

// 薪资方案生效时间
//
// 示例值：2022-10-20
func (builder *PlanDetailBuilder) EffectiveDate(effectiveDate string) *PlanDetailBuilder {
	builder.effectiveDate = effectiveDate
	builder.effectiveDateFlag = true
	return builder
}

// 薪资方案适用范围
//
// 示例值：
func (builder *PlanDetailBuilder) PlanScope(planScope *PlanScope) *PlanDetailBuilder {
	builder.planScope = planScope
	builder.planScopeFlag = true
	return builder
}

// 币种ID
//
// 示例值：341324121
func (builder *PlanDetailBuilder) CurrencyId(currencyId string) *PlanDetailBuilder {
	builder.currencyId = currencyId
	builder.currencyIdFlag = true
	return builder
}

// 开启试用期薪酬状态
//
// 示例值：true
func (builder *PlanDetailBuilder) ProbationSalaryStatus(probationSalaryStatus bool) *PlanDetailBuilder {
	builder.probationSalaryStatus = probationSalaryStatus
	builder.probationSalaryStatusFlag = true
	return builder
}

// 方案关联的薪资项
//
// 示例值：
func (builder *PlanDetailBuilder) PlanItems(planItems []*PlanItem) *PlanDetailBuilder {
	builder.planItems = planItems
	builder.planItemsFlag = true
	return builder
}

// 方案关联的薪资统计指标
//
// 示例值：
func (builder *PlanDetailBuilder) PlanIndicators(planIndicators []*PlanIndicator) *PlanDetailBuilder {
	builder.planIndicators = planIndicators
	builder.planIndicatorsFlag = true
	return builder
}

// 多语言名称
//
// 示例值：
func (builder *PlanDetailBuilder) I18nNames(i18nNames []*I18nContent) *PlanDetailBuilder {
	builder.i18nNames = i18nNames
	builder.i18nNamesFlag = true
	return builder
}

// 多语言描述
//
// 示例值：
func (builder *PlanDetailBuilder) I18nDescriptions(i18nDescriptions []*I18nContent) *PlanDetailBuilder {
	builder.i18nDescriptions = i18nDescriptions
	builder.i18nDescriptionsFlag = true
	return builder
}

func (builder *PlanDetailBuilder) Build() *PlanDetail {
	req := &PlanDetail{}
	if builder.idFlag {
		req.Id = &builder.id

	}
	if builder.tidFlag {
		req.Tid = &builder.tid

	}
	if builder.nameFlag {
		req.Name = &builder.name

	}
	if builder.descriptionFlag {
		req.Description = &builder.description

	}
	if builder.effectiveDateFlag {
		req.EffectiveDate = &builder.effectiveDate

	}
	if builder.planScopeFlag {
		req.PlanScope = builder.planScope
	}
	if builder.currencyIdFlag {
		req.CurrencyId = &builder.currencyId

	}
	if builder.probationSalaryStatusFlag {
		req.ProbationSalaryStatus = &builder.probationSalaryStatus

	}
	if builder.planItemsFlag {
		req.PlanItems = builder.planItems
	}
	if builder.planIndicatorsFlag {
		req.PlanIndicators = builder.planIndicators
	}
	if builder.i18nNamesFlag {
		req.I18nNames = builder.i18nNames
	}
	if builder.i18nDescriptionsFlag {
		req.I18nDescriptions = builder.i18nDescriptions
	}
	return req
}

type PlanIndicator struct {
	IndicatorId        *string          `json:"indicator_id,omitempty"`         // 薪资统计指标ID，详细信息可以通过[批量查询薪资统计指标](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/indicator/list)接口查询获得
	PlanIndicatorLogic *AdjustmentLogic `json:"plan_indicator_logic,omitempty"` // 方案关联薪资统计指标逻辑配置
}

type PlanIndicatorBuilder struct {
	indicatorId            string // 薪资统计指标ID，详细信息可以通过[批量查询薪资统计指标](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/indicator/list)接口查询获得
	indicatorIdFlag        bool
	planIndicatorLogic     *AdjustmentLogic // 方案关联薪资统计指标逻辑配置
	planIndicatorLogicFlag bool
}

func NewPlanIndicatorBuilder() *PlanIndicatorBuilder {
	builder := &PlanIndicatorBuilder{}
	return builder
}

// 薪资统计指标ID，详细信息可以通过[批量查询薪资统计指标](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/indicator/list)接口查询获得
//
// 示例值：13243432
func (builder *PlanIndicatorBuilder) IndicatorId(indicatorId string) *PlanIndicatorBuilder {
	builder.indicatorId = indicatorId
	builder.indicatorIdFlag = true
	return builder
}

// 方案关联薪资统计指标逻辑配置
//
// 示例值：
func (builder *PlanIndicatorBuilder) PlanIndicatorLogic(planIndicatorLogic *AdjustmentLogic) *PlanIndicatorBuilder {
	builder.planIndicatorLogic = planIndicatorLogic
	builder.planIndicatorLogicFlag = true
	return builder
}

func (builder *PlanIndicatorBuilder) Build() *PlanIndicator {
	req := &PlanIndicator{}
	if builder.indicatorIdFlag {
		req.IndicatorId = &builder.indicatorId

	}
	if builder.planIndicatorLogicFlag {
		req.PlanIndicatorLogic = builder.planIndicatorLogic
	}
	return req
}

type PlanItem struct {
	AdjustmentType             *string          `json:"adjustment_type,omitempty"`              // 定薪方式
	ItemId                     *string          `json:"item_id,omitempty"`                      // 薪资项ID，详细信息可以通过[批量查询薪资项](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/item/list)接口查询获得
	PlanItemLogic              *AdjustmentLogic `json:"plan_item_logic,omitempty"`              // 方案关联薪资项逻辑配置
	ProbationDiscountType      *string          `json:"probation_discount_type,omitempty"`      // 试用期薪酬类型
	ProbationDiscountPercentum *string          `json:"probation_discount_percentum,omitempty"` // 试用期薪酬百分比
}

type PlanItemBuilder struct {
	adjustmentType                 string // 定薪方式
	adjustmentTypeFlag             bool
	itemId                         string // 薪资项ID，详细信息可以通过[批量查询薪资项](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/item/list)接口查询获得
	itemIdFlag                     bool
	planItemLogic                  *AdjustmentLogic // 方案关联薪资项逻辑配置
	planItemLogicFlag              bool
	probationDiscountType          string // 试用期薪酬类型
	probationDiscountTypeFlag      bool
	probationDiscountPercentum     string // 试用期薪酬百分比
	probationDiscountPercentumFlag bool
}

func NewPlanItemBuilder() *PlanItemBuilder {
	builder := &PlanItemBuilder{}
	return builder
}

// 定薪方式
//
// 示例值：manual
func (builder *PlanItemBuilder) AdjustmentType(adjustmentType string) *PlanItemBuilder {
	builder.adjustmentType = adjustmentType
	builder.adjustmentTypeFlag = true
	return builder
}

// 薪资项ID，详细信息可以通过[批量查询薪资项](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/compensation-v1/item/list)接口查询获得
//
// 示例值：21341234
func (builder *PlanItemBuilder) ItemId(itemId string) *PlanItemBuilder {
	builder.itemId = itemId
	builder.itemIdFlag = true
	return builder
}

// 方案关联薪资项逻辑配置
//
// 示例值：
func (builder *PlanItemBuilder) PlanItemLogic(planItemLogic *AdjustmentLogic) *PlanItemBuilder {
	builder.planItemLogic = planItemLogic
	builder.planItemLogicFlag = true
	return builder
}

// 试用期薪酬类型
//
// 示例值：percentum
func (builder *PlanItemBuilder) ProbationDiscountType(probationDiscountType string) *PlanItemBuilder {
	builder.probationDiscountType = probationDiscountType
	builder.probationDiscountTypeFlag = true
	return builder
}

// 试用期薪酬百分比
//
// 示例值：80.00
func (builder *PlanItemBuilder) ProbationDiscountPercentum(probationDiscountPercentum string) *PlanItemBuilder {
	builder.probationDiscountPercentum = probationDiscountPercentum
	builder.probationDiscountPercentumFlag = true
	return builder
}

func (builder *PlanItemBuilder) Build() *PlanItem {
	req := &PlanItem{}
	if builder.adjustmentTypeFlag {
		req.AdjustmentType = &builder.adjustmentType

	}
	if builder.itemIdFlag {
		req.ItemId = &builder.itemId

	}
	if builder.planItemLogicFlag {
		req.PlanItemLogic = builder.planItemLogic
	}
	if builder.probationDiscountTypeFlag {
		req.ProbationDiscountType = &builder.probationDiscountType

	}
	if builder.probationDiscountPercentumFlag {
		req.ProbationDiscountPercentum = &builder.probationDiscountPercentum

	}
	return req
}

type PlanScope struct {
	IsAll          *bool            `json:"is_all,omitempty"`          // 是否全部范围
	PlanConditions []*PlanCondition `json:"plan_conditions,omitempty"` // 方案适用范围条件组
}

type PlanScopeBuilder struct {
	isAll              bool // 是否全部范围
	isAllFlag          bool
	planConditions     []*PlanCondition // 方案适用范围条件组
	planConditionsFlag bool
}

func NewPlanScopeBuilder() *PlanScopeBuilder {
	builder := &PlanScopeBuilder{}
	return builder
}

// 是否全部范围
//
// 示例值：false
func (builder *PlanScopeBuilder) IsAll(isAll bool) *PlanScopeBuilder {
	builder.isAll = isAll
	builder.isAllFlag = true
	return builder
}

// 方案适用范围条件组
//
// 示例值：
func (builder *PlanScopeBuilder) PlanConditions(planConditions []*PlanCondition) *PlanScopeBuilder {
	builder.planConditions = planConditions
	builder.planConditionsFlag = true
	return builder
}

func (builder *PlanScopeBuilder) Build() *PlanScope {
	req := &PlanScope{}
	if builder.isAllFlag {
		req.IsAll = &builder.isAll

	}
	if builder.planConditionsFlag {
		req.PlanConditions = builder.planConditions
	}
	return req
}

type QueryArchiveReqBodyBuilder struct {
	userIdList             []string // 用户ID列表
	userIdListFlag         bool
	effectiveStartDate     string // 生效开始时间
	effectiveStartDateFlag bool
	effectiveEndDate       string // 生效结束时间
	effectiveEndDateFlag   bool
}

func NewQueryArchiveReqBodyBuilder() *QueryArchiveReqBodyBuilder {
	builder := &QueryArchiveReqBodyBuilder{}
	return builder
}

// 用户ID列表
//
// 示例值：
func (builder *QueryArchiveReqBodyBuilder) UserIdList(userIdList []string) *QueryArchiveReqBodyBuilder {
	builder.userIdList = userIdList
	builder.userIdListFlag = true
	return builder
}

// 生效开始时间
//
// 示例值：2022-05-10
func (builder *QueryArchiveReqBodyBuilder) EffectiveStartDate(effectiveStartDate string) *QueryArchiveReqBodyBuilder {
	builder.effectiveStartDate = effectiveStartDate
	builder.effectiveStartDateFlag = true
	return builder
}

// 生效结束时间
//
// 示例值：2023-05-15
func (builder *QueryArchiveReqBodyBuilder) EffectiveEndDate(effectiveEndDate string) *QueryArchiveReqBodyBuilder {
	builder.effectiveEndDate = effectiveEndDate
	builder.effectiveEndDateFlag = true
	return builder
}

func (builder *QueryArchiveReqBodyBuilder) Build() *QueryArchiveReqBody {
	req := &QueryArchiveReqBody{}
	if builder.userIdListFlag {
		req.UserIdList = builder.userIdList
	}
	if builder.effectiveStartDateFlag {
		req.EffectiveStartDate = &builder.effectiveStartDate
	}
	if builder.effectiveEndDateFlag {
		req.EffectiveEndDate = &builder.effectiveEndDate
	}
	return req
}

type QueryArchivePathReqBodyBuilder struct {
	userIdList             []string
	userIdListFlag         bool
	effectiveStartDate     string
	effectiveStartDateFlag bool
	effectiveEndDate       string
	effectiveEndDateFlag   bool
}

func NewQueryArchivePathReqBodyBuilder() *QueryArchivePathReqBodyBuilder {
	builder := &QueryArchivePathReqBodyBuilder{}
	return builder
}

// 用户ID列表
//
// 示例值：
func (builder *QueryArchivePathReqBodyBuilder) UserIdList(userIdList []string) *QueryArchivePathReqBodyBuilder {
	builder.userIdList = userIdList
	builder.userIdListFlag = true
	return builder
}

// 生效开始时间
//
// 示例值：2022-05-10
func (builder *QueryArchivePathReqBodyBuilder) EffectiveStartDate(effectiveStartDate string) *QueryArchivePathReqBodyBuilder {
	builder.effectiveStartDate = effectiveStartDate
	builder.effectiveStartDateFlag = true
	return builder
}

// 生效结束时间
//
// 示例值：2023-05-15
func (builder *QueryArchivePathReqBodyBuilder) EffectiveEndDate(effectiveEndDate string) *QueryArchivePathReqBodyBuilder {
	builder.effectiveEndDate = effectiveEndDate
	builder.effectiveEndDateFlag = true
	return builder
}

func (builder *QueryArchivePathReqBodyBuilder) Build() (*QueryArchiveReqBody, error) {
	req := &QueryArchiveReqBody{}
	if builder.userIdListFlag {
		req.UserIdList = builder.userIdList
	}
	if builder.effectiveStartDateFlag {
		req.EffectiveStartDate = &builder.effectiveStartDate
	}
	if builder.effectiveEndDateFlag {
		req.EffectiveEndDate = &builder.effectiveEndDate
	}
	return req, nil
}

type QueryArchiveReqBuilder struct {
	apiReq *larkcore.ApiReq
	body   *QueryArchiveReqBody
}

func NewQueryArchiveReqBuilder() *QueryArchiveReqBuilder {
	builder := &QueryArchiveReqBuilder{}
	builder.apiReq = &larkcore.ApiReq{
		PathParams:  larkcore.PathParams{},
		QueryParams: larkcore.QueryParams{},
	}
	return builder
}

// 分页大小
//
// 示例值：100
func (builder *QueryArchiveReqBuilder) PageSize(pageSize int) *QueryArchiveReqBuilder {
	builder.apiReq.QueryParams.Set("page_size", fmt.Sprint(pageSize))
	return builder
}

// 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果
//
// 示例值：231432433
func (builder *QueryArchiveReqBuilder) PageToken(pageToken string) *QueryArchiveReqBuilder {
	builder.apiReq.QueryParams.Set("page_token", fmt.Sprint(pageToken))
	return builder
}

// 用户ID类型
//
// 示例值：open_id
func (builder *QueryArchiveReqBuilder) UserIdType(userIdType string) *QueryArchiveReqBuilder {
	builder.apiReq.QueryParams.Set("user_id_type", fmt.Sprint(userIdType))
	return builder
}

func (builder *QueryArchiveReqBuilder) Body(body *QueryArchiveReqBody) *QueryArchiveReqBuilder {
	builder.body = body
	return builder
}

func (builder *QueryArchiveReqBuilder) Build() *QueryArchiveReq {
	req := &QueryArchiveReq{}
	req.apiReq = &larkcore.ApiReq{}
	req.apiReq.QueryParams = builder.apiReq.QueryParams
	req.apiReq.Body = builder.body
	return req
}

type QueryArchiveReqBody struct {
	UserIdList         []string `json:"user_id_list,omitempty"`         // 用户ID列表
	EffectiveStartDate *string  `json:"effective_start_date,omitempty"` // 生效开始时间
	EffectiveEndDate   *string  `json:"effective_end_date,omitempty"`   // 生效结束时间
}

type QueryArchiveReq struct {
	apiReq *larkcore.ApiReq
	Body   *QueryArchiveReqBody `body:""`
}

type QueryArchiveRespData struct {
	Items     []*ArchiveDetail `json:"items,omitempty"`      // 档案信息列表
	PageToken *string          `json:"page_token,omitempty"` // 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
	HasMore   *bool            `json:"has_more,omitempty"`   // 是否还有更多项
}

type QueryArchiveResp struct {
	*larkcore.ApiResp `json:"-"`
	larkcore.CodeError
	Data *QueryArchiveRespData `json:"data"` // 业务数据
}

func (resp *QueryArchiveResp) Success() bool {
	return resp.Code == 0
}

type ListChangeReasonReqBuilder struct {
	apiReq *larkcore.ApiReq
	limit  int // 最大返回多少记录，当使用迭代器访问时才有效
}

func NewListChangeReasonReqBuilder() *ListChangeReasonReqBuilder {
	builder := &ListChangeReasonReqBuilder{}
	builder.apiReq = &larkcore.ApiReq{
		PathParams:  larkcore.PathParams{},
		QueryParams: larkcore.QueryParams{},
	}
	return builder
}

// 最大返回多少记录，当使用迭代器访问时才有效
func (builder *ListChangeReasonReqBuilder) Limit(limit int) *ListChangeReasonReqBuilder {
	builder.limit = limit
	return builder
}

// 分页大小
//
// 示例值：100
func (builder *ListChangeReasonReqBuilder) PageSize(pageSize int) *ListChangeReasonReqBuilder {
	builder.apiReq.QueryParams.Set("page_size", fmt.Sprint(pageSize))
	return builder
}

// 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果
//
// 示例值：12314342
func (builder *ListChangeReasonReqBuilder) PageToken(pageToken string) *ListChangeReasonReqBuilder {
	builder.apiReq.QueryParams.Set("page_token", fmt.Sprint(pageToken))
	return builder
}

func (builder *ListChangeReasonReqBuilder) Build() *ListChangeReasonReq {
	req := &ListChangeReasonReq{}
	req.apiReq = &larkcore.ApiReq{}
	req.Limit = builder.limit
	req.apiReq.QueryParams = builder.apiReq.QueryParams
	return req
}

type ListChangeReasonReq struct {
	apiReq *larkcore.ApiReq
	Limit  int // 最多返回多少记录，只有在使用迭代器访问时，才有效

}

type ListChangeReasonRespData struct {
	Items     []*ChangeReason `json:"items,omitempty"`      // 调薪原因信息列表
	PageToken *string         `json:"page_token,omitempty"` // 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
	HasMore   *bool           `json:"has_more,omitempty"`   // 是否还有更多项
}

type ListChangeReasonResp struct {
	*larkcore.ApiResp `json:"-"`
	larkcore.CodeError
	Data *ListChangeReasonRespData `json:"data"` // 业务数据
}

func (resp *ListChangeReasonResp) Success() bool {
	return resp.Code == 0
}

type ListIndicatorReqBuilder struct {
	apiReq *larkcore.ApiReq
	limit  int // 最大返回多少记录，当使用迭代器访问时才有效
}

func NewListIndicatorReqBuilder() *ListIndicatorReqBuilder {
	builder := &ListIndicatorReqBuilder{}
	builder.apiReq = &larkcore.ApiReq{
		PathParams:  larkcore.PathParams{},
		QueryParams: larkcore.QueryParams{},
	}
	return builder
}

// 最大返回多少记录，当使用迭代器访问时才有效
func (builder *ListIndicatorReqBuilder) Limit(limit int) *ListIndicatorReqBuilder {
	builder.limit = limit
	return builder
}

// 分页大小
//
// 示例值：100
func (builder *ListIndicatorReqBuilder) PageSize(pageSize int) *ListIndicatorReqBuilder {
	builder.apiReq.QueryParams.Set("page_size", fmt.Sprint(pageSize))
	return builder
}

// 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果
//
// 示例值：123423321
func (builder *ListIndicatorReqBuilder) PageToken(pageToken string) *ListIndicatorReqBuilder {
	builder.apiReq.QueryParams.Set("page_token", fmt.Sprint(pageToken))
	return builder
}

func (builder *ListIndicatorReqBuilder) Build() *ListIndicatorReq {
	req := &ListIndicatorReq{}
	req.apiReq = &larkcore.ApiReq{}
	req.Limit = builder.limit
	req.apiReq.QueryParams = builder.apiReq.QueryParams
	return req
}

type ListIndicatorReq struct {
	apiReq *larkcore.ApiReq
	Limit  int // 最多返回多少记录，只有在使用迭代器访问时，才有效

}

type ListIndicatorRespData struct {
	Items     []*Indicator `json:"items,omitempty"`      // 薪资统计指标信息列表
	PageToken *string      `json:"page_token,omitempty"` // 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
	HasMore   *bool        `json:"has_more,omitempty"`   // 是否还有更多项
}

type ListIndicatorResp struct {
	*larkcore.ApiResp `json:"-"`
	larkcore.CodeError
	Data *ListIndicatorRespData `json:"data"` // 业务数据
}

func (resp *ListIndicatorResp) Success() bool {
	return resp.Code == 0
}

type ListItemReqBuilder struct {
	apiReq *larkcore.ApiReq
	limit  int // 最大返回多少记录，当使用迭代器访问时才有效
}

func NewListItemReqBuilder() *ListItemReqBuilder {
	builder := &ListItemReqBuilder{}
	builder.apiReq = &larkcore.ApiReq{
		PathParams:  larkcore.PathParams{},
		QueryParams: larkcore.QueryParams{},
	}
	return builder
}

// 最大返回多少记录，当使用迭代器访问时才有效
func (builder *ListItemReqBuilder) Limit(limit int) *ListItemReqBuilder {
	builder.limit = limit
	return builder
}

// 分页大小
//
// 示例值：100
func (builder *ListItemReqBuilder) PageSize(pageSize int) *ListItemReqBuilder {
	builder.apiReq.QueryParams.Set("page_size", fmt.Sprint(pageSize))
	return builder
}

// 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果
//
// 示例值：5234233214
func (builder *ListItemReqBuilder) PageToken(pageToken string) *ListItemReqBuilder {
	builder.apiReq.QueryParams.Set("page_token", fmt.Sprint(pageToken))
	return builder
}

func (builder *ListItemReqBuilder) Build() *ListItemReq {
	req := &ListItemReq{}
	req.apiReq = &larkcore.ApiReq{}
	req.Limit = builder.limit
	req.apiReq.QueryParams = builder.apiReq.QueryParams
	return req
}

type ListItemReq struct {
	apiReq *larkcore.ApiReq
	Limit  int // 最多返回多少记录，只有在使用迭代器访问时，才有效

}

type ListItemRespData struct {
	Items     []*Item `json:"items,omitempty"`      // 薪资项信息列表
	PageToken *string `json:"page_token,omitempty"` // 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
	HasMore   *bool   `json:"has_more,omitempty"`   // 是否还有更多项
}

type ListItemResp struct {
	*larkcore.ApiResp `json:"-"`
	larkcore.CodeError
	Data *ListItemRespData `json:"data"` // 业务数据
}

func (resp *ListItemResp) Success() bool {
	return resp.Code == 0
}

type ListItemCategoryReqBuilder struct {
	apiReq *larkcore.ApiReq
	limit  int // 最大返回多少记录，当使用迭代器访问时才有效
}

func NewListItemCategoryReqBuilder() *ListItemCategoryReqBuilder {
	builder := &ListItemCategoryReqBuilder{}
	builder.apiReq = &larkcore.ApiReq{
		PathParams:  larkcore.PathParams{},
		QueryParams: larkcore.QueryParams{},
	}
	return builder
}

// 最大返回多少记录，当使用迭代器访问时才有效
func (builder *ListItemCategoryReqBuilder) Limit(limit int) *ListItemCategoryReqBuilder {
	builder.limit = limit
	return builder
}

// 分页大小
//
// 示例值：100
func (builder *ListItemCategoryReqBuilder) PageSize(pageSize int) *ListItemCategoryReqBuilder {
	builder.apiReq.QueryParams.Set("page_size", fmt.Sprint(pageSize))
	return builder
}

// 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果
//
// 示例值：231412341234
func (builder *ListItemCategoryReqBuilder) PageToken(pageToken string) *ListItemCategoryReqBuilder {
	builder.apiReq.QueryParams.Set("page_token", fmt.Sprint(pageToken))
	return builder
}

func (builder *ListItemCategoryReqBuilder) Build() *ListItemCategoryReq {
	req := &ListItemCategoryReq{}
	req.apiReq = &larkcore.ApiReq{}
	req.Limit = builder.limit
	req.apiReq.QueryParams = builder.apiReq.QueryParams
	return req
}

type ListItemCategoryReq struct {
	apiReq *larkcore.ApiReq
	Limit  int // 最多返回多少记录，只有在使用迭代器访问时，才有效

}

type ListItemCategoryRespData struct {
	Items     []*ItemCategory `json:"items,omitempty"`      // 薪资项分类信息列表
	PageToken *string         `json:"page_token,omitempty"` // 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
	HasMore   *bool           `json:"has_more,omitempty"`   // 是否还有更多项
}

type ListItemCategoryResp struct {
	*larkcore.ApiResp `json:"-"`
	larkcore.CodeError
	Data *ListItemCategoryRespData `json:"data"` // 业务数据
}

func (resp *ListItemCategoryResp) Success() bool {
	return resp.Code == 0
}

type ListPlanReqBuilder struct {
	apiReq *larkcore.ApiReq
	limit  int // 最大返回多少记录，当使用迭代器访问时才有效
}

func NewListPlanReqBuilder() *ListPlanReqBuilder {
	builder := &ListPlanReqBuilder{}
	builder.apiReq = &larkcore.ApiReq{
		PathParams:  larkcore.PathParams{},
		QueryParams: larkcore.QueryParams{},
	}
	return builder
}

// 最大返回多少记录，当使用迭代器访问时才有效
func (builder *ListPlanReqBuilder) Limit(limit int) *ListPlanReqBuilder {
	builder.limit = limit
	return builder
}

// 分页大小
//
// 示例值：100
func (builder *ListPlanReqBuilder) PageSize(pageSize int) *ListPlanReqBuilder {
	builder.apiReq.QueryParams.Set("page_size", fmt.Sprint(pageSize))
	return builder
}

// 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果
//
// 示例值：213432123
func (builder *ListPlanReqBuilder) PageToken(pageToken string) *ListPlanReqBuilder {
	builder.apiReq.QueryParams.Set("page_token", fmt.Sprint(pageToken))
	return builder
}

func (builder *ListPlanReqBuilder) Build() *ListPlanReq {
	req := &ListPlanReq{}
	req.apiReq = &larkcore.ApiReq{}
	req.Limit = builder.limit
	req.apiReq.QueryParams = builder.apiReq.QueryParams
	return req
}

type ListPlanReq struct {
	apiReq *larkcore.ApiReq
	Limit  int // 最多返回多少记录，只有在使用迭代器访问时，才有效

}

type ListPlanRespData struct {
	Items     []*PlanDetail `json:"items,omitempty"`      // 薪资方案信息列表
	PageToken *string       `json:"page_token,omitempty"` // 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
	HasMore   *bool         `json:"has_more,omitempty"`   // 是否还有更多项
}

type ListPlanResp struct {
	*larkcore.ApiResp `json:"-"`
	larkcore.CodeError
	Data *ListPlanRespData `json:"data"` // 业务数据
}

func (resp *ListPlanResp) Success() bool {
	return resp.Code == 0
}

type ListChangeReasonIterator struct {
	nextPageToken *string
	items         []*ChangeReason
	index         int
	limit         int
	ctx           context.Context
	req           *ListChangeReasonReq
	listFunc      func(ctx context.Context, req *ListChangeReasonReq, options ...larkcore.RequestOptionFunc) (*ListChangeReasonResp, error)
	options       []larkcore.RequestOptionFunc
	curlNum       int
}

func (iterator *ListChangeReasonIterator) Next() (bool, *ChangeReason, error) {
	// 达到最大量，则返回
	if iterator.limit > 0 && iterator.curlNum >= iterator.limit {
		return false, nil, nil
	}

	// 为0则拉取数据
	if iterator.index == 0 || iterator.index >= len(iterator.items) {
		if iterator.index != 0 && iterator.nextPageToken == nil {
			return false, nil, nil
		}
		if iterator.nextPageToken != nil {
			iterator.req.apiReq.QueryParams.Set("page_token", *iterator.nextPageToken)
		}
		resp, err := iterator.listFunc(iterator.ctx, iterator.req, iterator.options...)
		if err != nil {
			return false, nil, err
		}

		if resp.Code != 0 {
			return false, nil, errors.New(fmt.Sprintf("Code:%d,Msg:%s", resp.Code, resp.Msg))
		}

		if len(resp.Data.Items) == 0 {
			return false, nil, nil
		}

		iterator.nextPageToken = resp.Data.PageToken
		iterator.items = resp.Data.Items
		iterator.index = 0
	}

	block := iterator.items[iterator.index]
	iterator.index++
	iterator.curlNum++
	return true, block, nil
}

func (iterator *ListChangeReasonIterator) NextPageToken() *string {
	return iterator.nextPageToken
}

type ListIndicatorIterator struct {
	nextPageToken *string
	items         []*Indicator
	index         int
	limit         int
	ctx           context.Context
	req           *ListIndicatorReq
	listFunc      func(ctx context.Context, req *ListIndicatorReq, options ...larkcore.RequestOptionFunc) (*ListIndicatorResp, error)
	options       []larkcore.RequestOptionFunc
	curlNum       int
}

func (iterator *ListIndicatorIterator) Next() (bool, *Indicator, error) {
	// 达到最大量，则返回
	if iterator.limit > 0 && iterator.curlNum >= iterator.limit {
		return false, nil, nil
	}

	// 为0则拉取数据
	if iterator.index == 0 || iterator.index >= len(iterator.items) {
		if iterator.index != 0 && iterator.nextPageToken == nil {
			return false, nil, nil
		}
		if iterator.nextPageToken != nil {
			iterator.req.apiReq.QueryParams.Set("page_token", *iterator.nextPageToken)
		}
		resp, err := iterator.listFunc(iterator.ctx, iterator.req, iterator.options...)
		if err != nil {
			return false, nil, err
		}

		if resp.Code != 0 {
			return false, nil, errors.New(fmt.Sprintf("Code:%d,Msg:%s", resp.Code, resp.Msg))
		}

		if len(resp.Data.Items) == 0 {
			return false, nil, nil
		}

		iterator.nextPageToken = resp.Data.PageToken
		iterator.items = resp.Data.Items
		iterator.index = 0
	}

	block := iterator.items[iterator.index]
	iterator.index++
	iterator.curlNum++
	return true, block, nil
}

func (iterator *ListIndicatorIterator) NextPageToken() *string {
	return iterator.nextPageToken
}

type ListItemIterator struct {
	nextPageToken *string
	items         []*Item
	index         int
	limit         int
	ctx           context.Context
	req           *ListItemReq
	listFunc      func(ctx context.Context, req *ListItemReq, options ...larkcore.RequestOptionFunc) (*ListItemResp, error)
	options       []larkcore.RequestOptionFunc
	curlNum       int
}

func (iterator *ListItemIterator) Next() (bool, *Item, error) {
	// 达到最大量，则返回
	if iterator.limit > 0 && iterator.curlNum >= iterator.limit {
		return false, nil, nil
	}

	// 为0则拉取数据
	if iterator.index == 0 || iterator.index >= len(iterator.items) {
		if iterator.index != 0 && iterator.nextPageToken == nil {
			return false, nil, nil
		}
		if iterator.nextPageToken != nil {
			iterator.req.apiReq.QueryParams.Set("page_token", *iterator.nextPageToken)
		}
		resp, err := iterator.listFunc(iterator.ctx, iterator.req, iterator.options...)
		if err != nil {
			return false, nil, err
		}

		if resp.Code != 0 {
			return false, nil, errors.New(fmt.Sprintf("Code:%d,Msg:%s", resp.Code, resp.Msg))
		}

		if len(resp.Data.Items) == 0 {
			return false, nil, nil
		}

		iterator.nextPageToken = resp.Data.PageToken
		iterator.items = resp.Data.Items
		iterator.index = 0
	}

	block := iterator.items[iterator.index]
	iterator.index++
	iterator.curlNum++
	return true, block, nil
}

func (iterator *ListItemIterator) NextPageToken() *string {
	return iterator.nextPageToken
}

type ListItemCategoryIterator struct {
	nextPageToken *string
	items         []*ItemCategory
	index         int
	limit         int
	ctx           context.Context
	req           *ListItemCategoryReq
	listFunc      func(ctx context.Context, req *ListItemCategoryReq, options ...larkcore.RequestOptionFunc) (*ListItemCategoryResp, error)
	options       []larkcore.RequestOptionFunc
	curlNum       int
}

func (iterator *ListItemCategoryIterator) Next() (bool, *ItemCategory, error) {
	// 达到最大量，则返回
	if iterator.limit > 0 && iterator.curlNum >= iterator.limit {
		return false, nil, nil
	}

	// 为0则拉取数据
	if iterator.index == 0 || iterator.index >= len(iterator.items) {
		if iterator.index != 0 && iterator.nextPageToken == nil {
			return false, nil, nil
		}
		if iterator.nextPageToken != nil {
			iterator.req.apiReq.QueryParams.Set("page_token", *iterator.nextPageToken)
		}
		resp, err := iterator.listFunc(iterator.ctx, iterator.req, iterator.options...)
		if err != nil {
			return false, nil, err
		}

		if resp.Code != 0 {
			return false, nil, errors.New(fmt.Sprintf("Code:%d,Msg:%s", resp.Code, resp.Msg))
		}

		if len(resp.Data.Items) == 0 {
			return false, nil, nil
		}

		iterator.nextPageToken = resp.Data.PageToken
		iterator.items = resp.Data.Items
		iterator.index = 0
	}

	block := iterator.items[iterator.index]
	iterator.index++
	iterator.curlNum++
	return true, block, nil
}

func (iterator *ListItemCategoryIterator) NextPageToken() *string {
	return iterator.nextPageToken
}

type ListPlanIterator struct {
	nextPageToken *string
	items         []*PlanDetail
	index         int
	limit         int
	ctx           context.Context
	req           *ListPlanReq
	listFunc      func(ctx context.Context, req *ListPlanReq, options ...larkcore.RequestOptionFunc) (*ListPlanResp, error)
	options       []larkcore.RequestOptionFunc
	curlNum       int
}

func (iterator *ListPlanIterator) Next() (bool, *PlanDetail, error) {
	// 达到最大量，则返回
	if iterator.limit > 0 && iterator.curlNum >= iterator.limit {
		return false, nil, nil
	}

	// 为0则拉取数据
	if iterator.index == 0 || iterator.index >= len(iterator.items) {
		if iterator.index != 0 && iterator.nextPageToken == nil {
			return false, nil, nil
		}
		if iterator.nextPageToken != nil {
			iterator.req.apiReq.QueryParams.Set("page_token", *iterator.nextPageToken)
		}
		resp, err := iterator.listFunc(iterator.ctx, iterator.req, iterator.options...)
		if err != nil {
			return false, nil, err
		}

		if resp.Code != 0 {
			return false, nil, errors.New(fmt.Sprintf("Code:%d,Msg:%s", resp.Code, resp.Msg))
		}

		if len(resp.Data.Items) == 0 {
			return false, nil, nil
		}

		iterator.nextPageToken = resp.Data.PageToken
		iterator.items = resp.Data.Items
		iterator.index = 0
	}

	block := iterator.items[iterator.index]
	iterator.index++
	iterator.curlNum++
	return true, block, nil
}

func (iterator *ListPlanIterator) NextPageToken() *string {
	return iterator.nextPageToken
}
